summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopetechatsession.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:34 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:34 -0600
commit83677e35509b4dafac63b76995652bdf3b49f209 (patch)
tree591f1dc22278addb439726c42896376b17bb42bd /kopete/libkopete/kopetechatsession.h
parent808e453c56036211f57482ed847d54aca01bba68 (diff)
downloadtdenetwork-83677e35509b4dafac63b76995652bdf3b49f209.tar.gz
tdenetwork-83677e35509b4dafac63b76995652bdf3b49f209.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 808e453c56036211f57482ed847d54aca01bba68.
Diffstat (limited to 'kopete/libkopete/kopetechatsession.h')
-rw-r--r--kopete/libkopete/kopetechatsession.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kopete/libkopete/kopetechatsession.h b/kopete/libkopete/kopetechatsession.h
index cab992c9..802a4e39 100644
--- a/kopete/libkopete/kopetechatsession.h
+++ b/kopete/libkopete/kopetechatsession.h
@@ -130,7 +130,7 @@ public:
* Set a special icon for a contact in this kmm only.
* by default, all contact have their own status
*/
- void setContactOnlineStatus( const Contact *contact, const OnlineStatus &newStatus );
+ void setContactOnlineStatus( const Contact *contact, const OnlineStatus &newtqStatus );
/**
* @brief get the status of a contact.
@@ -296,13 +296,13 @@ public slots:
/**
* Add a contact to the session with a pre-set initial status
* @param c is the contact
* @param initialStatus The initial contactOnlineStatus of the contact
* @param suppress mean the there will be no automatic notifications in the chatwindow.
* (note that i don't like the param suppress at all. it is used in irc to show a different notification (with an info text)
* a TQStringinfo would be more interesting, but it is also used to don't show the notification when entering in a channel)
* @see contactOnlineStatus
*/
- void addContact( const Kopete::Contact *c, const Kopete::OnlineStatus &initialStatus, bool suppress = false );
+ void addContact( const Kopete::Contact *c, const Kopete::OnlineStatus &initialtqStatus, bool suppress = false );
/**
* Remove a contact from the session
@@ -371,7 +371,7 @@ public slots:
private slots:
void slotUpdateDisplayName();
void slotViewDestroyed();
- void slotOnlineStatusChanged( Kopete::Contact *c, const Kopete::OnlineStatus &status, const Kopete::OnlineStatus &oldStatus );
+ void slotOnlineStatusChanged( Kopete::Contact *c, const Kopete::OnlineStatus &status, const Kopete::OnlineStatus &oldtqStatus );
void slotContactDestroyed( Kopete::Contact *contact );
protected:
@@ -296,13 +296,13 @@ public slots:
* Add a contact to the session with a pre-set initial status
* @param c is the contact
- * @param initialStatus The initial contactOnlineStatus of the contact
+ * @param initialtqStatus The initial contactOnlineStatus of the contact
* @param suppress mean the there will be no automatic notifications in the chatwindow.
* (note that i don't like the param suppress at all. it is used in irc to show a different notification (with an info text)